KeymapCollection

Struct KeymapCollection 

pub struct KeymapCollection { /* private fields */ }
A collection of keymaps, typically loaded from multiple files

Implementations

Source

impl KeymapCollection

pub fn new() -> KeymapCollection

Create a new empty keymap collection

Examples found in repository?
examples/editor_demo.rs (line 352)
350fn load_keymaps(cx: &mut App) {
351    // Load keymaps from JSON configuration
352    let mut keymap_collection = KeymapCollection::new();
353
354    let keymap_path = Path::new("examples/demo-keymap.json");
355    let loaded_from_file = if keymap_path.exists() {
356        match keymap_collection.load_file(keymap_path) {
357            Ok(_) => {
358                println!("Loaded keymaps from file: {}", keymap_path.display());
359                true
360            }
361            Err(e) => {
362                eprintln!("Failed to load keymap file: {}", e);
363                false
364            }
365        }
366    } else {
367        false
368    };
369
370    if !loaded_from_file {
371        let demo_keymap = include_str!("demo-keymap.json");
372        keymap_collection
373            .load_json(demo_keymap)
374            .expect("Failed to load embedded demo keymaps");
375        println!("Loaded embedded demo keymaps");
376    }
377
378    let specs = keymap_collection.get_binding_specs();
379
380    let mut bindings = Vec::new();
381
382    for spec in specs {
383        if !spec.action_name.starts_with("editor::") {
384            continue;
385        }
386
387        let action_name = spec
388            .action_name
389            .strip_prefix("editor::")
390            .unwrap_or(&spec.action_name);
391        let context = spec.context.as_deref();
392
393        match action_name {
394            "MoveUp" => bindings.push(KeyBinding::new(&spec.keystrokes, MoveUp, context)),
395            "MoveDown" => bindings.push(KeyBinding::new(&spec.keystrokes, MoveDown, context)),
396            "MoveLeft" => bindings.push(KeyBinding::new(&spec.keystrokes, MoveLeft, context)),
397            "MoveRight" => bindings.push(KeyBinding::new(&spec.keystrokes, MoveRight, context)),
398            "MoveUpWithShift" => {
399                bindings.push(KeyBinding::new(&spec.keystrokes, MoveUpWithShift, context))
400            }
401            "MoveDownWithShift" => bindings.push(KeyBinding::new(
402                &spec.keystrokes,
403                MoveDownWithShift,
404                context,
405            )),
406            "MoveLeftWithShift" => bindings.push(KeyBinding::new(
407                &spec.keystrokes,
408                MoveLeftWithShift,
409                context,
410            )),
411            "MoveRightWithShift" => bindings.push(KeyBinding::new(
412                &spec.keystrokes,
413                MoveRightWithShift,
414                context,
415            )),
416            "Backspace" => bindings.push(KeyBinding::new(&spec.keystrokes, Backspace, context)),
417            "Delete" => bindings.push(KeyBinding::new(&spec.keystrokes, Delete, context)),
418            "InsertNewline" => {
419                bindings.push(KeyBinding::new(&spec.keystrokes, InsertNewline, context))
420            }
421            "SelectAll" => bindings.push(KeyBinding::new(&spec.keystrokes, SelectAll, context)),
422            "Escape" => bindings.push(KeyBinding::new(&spec.keystrokes, Escape, context)),
423            "Copy" => bindings.push(KeyBinding::new(&spec.keystrokes, Copy, context)),
424            "Cut" => bindings.push(KeyBinding::new(&spec.keystrokes, Cut, context)),
425            "Paste" => bindings.push(KeyBinding::new(&spec.keystrokes, Paste, context)),
426            "NextTheme" => bindings.push(KeyBinding::new(&spec.keystrokes, NextTheme, context)),
427            "PreviousTheme" => {
428                bindings.push(KeyBinding::new(&spec.keystrokes, PreviousTheme, context))
429            }
430            "NextLanguage" => {
431                bindings.push(KeyBinding::new(&spec.keystrokes, NextLanguage, context))
432            }
433            "PreviousLanguage" => {
434                bindings.push(KeyBinding::new(&spec.keystrokes, PreviousLanguage, context))
435            }
436            unknown => {
437                eprintln!("Unknown editor action: {}", unknown);
438            }
439        }
440    }
441
442    println!(
443        "Registered {} keybindings from configuration",
444        bindings.len()
445    );
446    cx.bind_keys(bindings);
447}
pub fn load_file<P>(&mut self, path: P) -> Result<(), Error>
where P: AsRef<Path>,

Load a keymap from a JSON file

Examples found in repository?
examples/editor_demo.rs (line 356)
350fn load_keymaps(cx: &mut App) {
351    // Load keymaps from JSON configuration
352    let mut keymap_collection = KeymapCollection::new();
353
354    let keymap_path = Path::new("examples/demo-keymap.json");
355    let loaded_from_file = if keymap_path.exists() {
356        match keymap_collection.load_file(keymap_path) {
357            Ok(_) => {
358                println!("Loaded keymaps from file: {}", keymap_path.display());
359                true
360            }
361            Err(e) => {
362                eprintln!("Failed to load keymap file: {}", e);
363                false
364            }
365        }
366    } else {
367        false
368    };
369
370    if !loaded_from_file {
371        let demo_keymap = include_str!("demo-keymap.json");
372        keymap_collection
373            .load_json(demo_keymap)
374            .expect("Failed to load embedded demo keymaps");
375        println!("Loaded embedded demo keymaps");
376    }
377
378    let specs = keymap_collection.get_binding_specs();
379
380    let mut bindings = Vec::new();
381
382    for spec in specs {
383        if !spec.action_name.starts_with("editor::") {
384            continue;
385        }
386
387        let action_name = spec
388            .action_name
389            .strip_prefix("editor::")
390            .unwrap_or(&spec.action_name);
391        let context = spec.context.as_deref();
392
393        match action_name {
394            "MoveUp" => bindings.push(KeyBinding::new(&spec.keystrokes, MoveUp, context)),
395            "MoveDown" => bindings.push(KeyBinding::new(&spec.keystrokes, MoveDown, context)),
396            "MoveLeft" => bindings.push(KeyBinding::new(&spec.keystrokes, MoveLeft, context)),
397            "MoveRight" => bindings.push(KeyBinding::new(&spec.keystrokes, MoveRight, context)),
398            "MoveUpWithShift" => {
399                bindings.push(KeyBinding::new(&spec.keystrokes, MoveUpWithShift, context))
400            }
401            "MoveDownWithShift" => bindings.push(KeyBinding::new(
402                &spec.keystrokes,
403                MoveDownWithShift,
404                context,
405            )),
406            "MoveLeftWithShift" => bindings.push(KeyBinding::new(
407                &spec.keystrokes,
408                MoveLeftWithShift,
409                context,
410            )),
411            "MoveRightWithShift" => bindings.push(KeyBinding::new(
412                &spec.keystrokes,
413                MoveRightWithShift,
414                context,
415            )),
416            "Backspace" => bindings.push(KeyBinding::new(&spec.keystrokes, Backspace, context)),
417            "Delete" => bindings.push(KeyBinding::new(&spec.keystrokes, Delete, context)),
418            "InsertNewline" => {
419                bindings.push(KeyBinding::new(&spec.keystrokes, InsertNewline, context))
420            }
421            "SelectAll" => bindings.push(KeyBinding::new(&spec.keystrokes, SelectAll, context)),
422            "Escape" => bindings.push(KeyBinding::new(&spec.keystrokes, Escape, context)),
423            "Copy" => bindings.push(KeyBinding::new(&spec.keystrokes, Copy, context)),
424            "Cut" => bindings.push(KeyBinding::new(&spec.keystrokes, Cut, context)),
425            "Paste" => bindings.push(KeyBinding::new(&spec.keystrokes, Paste, context)),
426            "NextTheme" => bindings.push(KeyBinding::new(&spec.keystrokes, NextTheme, context)),
427            "PreviousTheme" => {
428                bindings.push(KeyBinding::new(&spec.keystrokes, PreviousTheme, context))
429            }
430            "NextLanguage" => {
431                bindings.push(KeyBinding::new(&spec.keystrokes, NextLanguage, context))
432            }
433            "PreviousLanguage" => {
434                bindings.push(KeyBinding::new(&spec.keystrokes, PreviousLanguage, context))
435            }
436            unknown => {
437                eprintln!("Unknown editor action: {}", unknown);
438            }
439        }
440    }
441
442    println!(
443        "Registered {} keybindings from configuration",
444        bindings.len()
445    );
446    cx.bind_keys(bindings);
447}
pub fn load_json(&mut self, json: &str) -> Result<(), Error>

Load keymaps from a JSON string

Examples found in repository?
examples/editor_demo.rs (line 373)
350fn load_keymaps(cx: &mut App) {
351    // Load keymaps from JSON configuration
352    let mut keymap_collection = KeymapCollection::new();
353
354    let keymap_path = Path::new("examples/demo-keymap.json");
355    let loaded_from_file = if keymap_path.exists() {
356        match keymap_collection.load_file(keymap_path) {
357            Ok(_) => {
358                println!("Loaded keymaps from file: {}", keymap_path.display());
359                true
360            }
361            Err(e) => {
362                eprintln!("Failed to load keymap file: {}", e);
363                false
364            }
365        }
366    } else {
367        false
368    };
369
370    if !loaded_from_file {
371        let demo_keymap = include_str!("demo-keymap.json");
372        keymap_collection
373            .load_json(demo_keymap)
374            .expect("Failed to load embedded demo keymaps");
375        println!("Loaded embedded demo keymaps");
376    }
377
378    let specs = keymap_collection.get_binding_specs();
379
380    let mut bindings = Vec::new();
381
382    for spec in specs {
383        if !spec.action_name.starts_with("editor::") {
384            continue;
385        }
386
387        let action_name = spec
388            .action_name
389            .strip_prefix("editor::")
390            .unwrap_or(&spec.action_name);
391        let context = spec.context.as_deref();
392
393        match action_name {
394            "MoveUp" => bindings.push(KeyBinding::new(&spec.keystrokes, MoveUp, context)),
395            "MoveDown" => bindings.push(KeyBinding::new(&spec.keystrokes, MoveDown, context)),
396            "MoveLeft" => bindings.push(KeyBinding::new(&spec.keystrokes, MoveLeft, context)),
397            "MoveRight" => bindings.push(KeyBinding::new(&spec.keystrokes, MoveRight, context)),
398            "MoveUpWithShift" => {
399                bindings.push(KeyBinding::new(&spec.keystrokes, MoveUpWithShift, context))
400            }
401            "MoveDownWithShift" => bindings.push(KeyBinding::new(
402                &spec.keystrokes,
403                MoveDownWithShift,
404                context,
405            )),
406            "MoveLeftWithShift" => bindings.push(KeyBinding::new(
407                &spec.keystrokes,
408                MoveLeftWithShift,
409                context,
410            )),
411            "MoveRightWithShift" => bindings.push(KeyBinding::new(
412                &spec.keystrokes,
413                MoveRightWithShift,
414                context,
415            )),
416            "Backspace" => bindings.push(KeyBinding::new(&spec.keystrokes, Backspace, context)),
417            "Delete" => bindings.push(KeyBinding::new(&spec.keystrokes, Delete, context)),
418            "InsertNewline" => {
419                bindings.push(KeyBinding::new(&spec.keystrokes, InsertNewline, context))
420            }
421            "SelectAll" => bindings.push(KeyBinding::new(&spec.keystrokes, SelectAll, context)),
422            "Escape" => bindings.push(KeyBinding::new(&spec.keystrokes, Escape, context)),
423            "Copy" => bindings.push(KeyBinding::new(&spec.keystrokes, Copy, context)),
424            "Cut" => bindings.push(KeyBinding::new(&spec.keystrokes, Cut, context)),
425            "Paste" => bindings.push(KeyBinding::new(&spec.keystrokes, Paste, context)),
426            "NextTheme" => bindings.push(KeyBinding::new(&spec.keystrokes, NextTheme, context)),
427            "PreviousTheme" => {
428                bindings.push(KeyBinding::new(&spec.keystrokes, PreviousTheme, context))
429            }
430            "NextLanguage" => {
431                bindings.push(KeyBinding::new(&spec.keystrokes, NextLanguage, context))
432            }
433            "PreviousLanguage" => {
434                bindings.push(KeyBinding::new(&spec.keystrokes, PreviousLanguage, context))
435            }
436            unknown => {
437                eprintln!("Unknown editor action: {}", unknown);
438            }
439        }
440    }
441
442    println!(
443        "Registered {} keybindings from configuration",
444        bindings.len()
445    );
446    cx.bind_keys(bindings);
447}
pub fn load_defaults(&mut self) -> Result<(), Error>

Load default keymaps

pub fn get_binding_specs(&self) -> Vec<BindingSpec>

Get all key binding specifications from this collection

Returns a list of binding specifications that can be used to create actual GPUI key bindings with concrete action types.

Examples found in repository?
examples/editor_demo.rs (line 378)
350fn load_keymaps(cx: &mut App) {
351    // Load keymaps from JSON configuration
352    let mut keymap_collection = KeymapCollection::new();
353
354    let keymap_path = Path::new("examples/demo-keymap.json");
355    let loaded_from_file = if keymap_path.exists() {
356        match keymap_collection.load_file(keymap_path) {
357            Ok(_) => {
358                println!("Loaded keymaps from file: {}", keymap_path.display());
359                true
360            }
361            Err(e) => {
362                eprintln!("Failed to load keymap file: {}", e);
363                false
364            }
365        }
366    } else {
367        false
368    };
369
370    if !loaded_from_file {
371        let demo_keymap = include_str!("demo-keymap.json");
372        keymap_collection
373            .load_json(demo_keymap)
374            .expect("Failed to load embedded demo keymaps");
375        println!("Loaded embedded demo keymaps");
376    }
377
378    let specs = keymap_collection.get_binding_specs();
379
380    let mut bindings = Vec::new();
381
382    for spec in specs {
383        if !spec.action_name.starts_with("editor::") {
384            continue;
385        }
386
387        let action_name = spec
388            .action_name
389            .strip_prefix("editor::")
390            .unwrap_or(&spec.action_name);
391        let context = spec.context.as_deref();
392
393        match action_name {
394            "MoveUp" => bindings.push(KeyBinding::new(&spec.keystrokes, MoveUp, context)),
395            "MoveDown" => bindings.push(KeyBinding::new(&spec.keystrokes, MoveDown, context)),
396            "MoveLeft" => bindings.push(KeyBinding::new(&spec.keystrokes, MoveLeft, context)),
397            "MoveRight" => bindings.push(KeyBinding::new(&spec.keystrokes, MoveRight, context)),
398            "MoveUpWithShift" => {
399                bindings.push(KeyBinding::new(&spec.keystrokes, MoveUpWithShift, context))
400            }
401            "MoveDownWithShift" => bindings.push(KeyBinding::new(
402                &spec.keystrokes,
403                MoveDownWithShift,
404                context,
405            )),
406            "MoveLeftWithShift" => bindings.push(KeyBinding::new(
407                &spec.keystrokes,
408                MoveLeftWithShift,
409                context,
410            )),
411            "MoveRightWithShift" => bindings.push(KeyBinding::new(
412                &spec.keystrokes,
413                MoveRightWithShift,
414                context,
415            )),
416            "Backspace" => bindings.push(KeyBinding::new(&spec.keystrokes, Backspace, context)),
417            "Delete" => bindings.push(KeyBinding::new(&spec.keystrokes, Delete, context)),
418            "InsertNewline" => {
419                bindings.push(KeyBinding::new(&spec.keystrokes, InsertNewline, context))
420            }
421            "SelectAll" => bindings.push(KeyBinding::new(&spec.keystrokes, SelectAll, context)),
422            "Escape" => bindings.push(KeyBinding::new(&spec.keystrokes, Escape, context)),
423            "Copy" => bindings.push(KeyBinding::new(&spec.keystrokes, Copy, context)),
424            "Cut" => bindings.push(KeyBinding::new(&spec.keystrokes, Cut, context)),
425            "Paste" => bindings.push(KeyBinding::new(&spec.keystrokes, Paste, context)),
426            "NextTheme" => bindings.push(KeyBinding::new(&spec.keystrokes, NextTheme, context)),
427            "PreviousTheme" => {
428                bindings.push(KeyBinding::new(&spec.keystrokes, PreviousTheme, context))
429            }
430            "NextLanguage" => {
431                bindings.push(KeyBinding::new(&spec.keystrokes, NextLanguage, context))
432            }
433            "PreviousLanguage" => {
434                bindings.push(KeyBinding::new(&spec.keystrokes, PreviousLanguage, context))
435            }
436            unknown => {
437                eprintln!("Unknown editor action: {}", unknown);
438            }
439        }
440    }
441
442    println!(
443        "Registered {} keybindings from configuration",
444        bindings.len()
445    );
446    cx.bind_keys(bindings);
447}
pub fn keymaps(&self) -> &[Keymap]

Get all keymaps in this collection

pub fn add(&mut self, keymap: Keymap)

Add a keymap to this collection

pub fn clear(&mut self)

Clear all keymaps from this collection

pub fn find_bindings_for_action(&self, action_name: &str) -> Vec<BindingSpec>

Find all bindings for a given action

pub fn find_action( &self, keystrokes: &str, context: Option<&str>, ) -> Option<&str>

Find the action for a given keystroke in a context